/*
 * Copyright (c) 2009, Willow Garage, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Willow Garage, Inc. nor the names of its
 *       contributors may be used to endorse or promote products derived from
 *       this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef RXTOOLS_LOGGER_LEVEL_PANEL_H
#define RXTOOLS_LOGGER_LEVEL_PANEL_H

#include "rosout_generated.h"

#include <boost/thread/thread.hpp>
#include <ros/ros.h>

#include <map>

class wxEvent;

namespace rxtools
{

class LoggerLevelPanel : public LoggerLevelPanelBase
{
public:
  LoggerLevelPanel(wxWindow* parent, int id = wxID_ANY, wxPoint pos = wxDefaultPosition, wxSize size = wxDefaultSize, int style = wxTAB_TRAVERSAL);
  ~LoggerLevelPanel();

  void refresh();

protected:
  void fillNodeList();

  virtual void onNodesRefresh( wxCommandEvent& event );
  virtual void onNodeSelected( wxCommandEvent& event );
  virtual void onLoggerSelected( wxCommandEvent& event );
  virtual void onLevelSelected( wxCommandEvent& event );

  ros::NodeHandle nh_;

  typedef std::map<std::string, std::string> M_string;
  M_string loggers_;

  void checkForMaster();
  bool connected_; ///< Are we connected to master?
  boost::thread* check_master_thread_; ///< Thread used to periodically check for master
  bool shutdown_thread_; ///< Should the thread terminate?

  const int RECONNECTED_TO_MASTER_EVENT_;
  const int DISCONNECTED_FROM_MASTER_EVENT_;
  void onMasterReconnected(wxEvent& event);
  void onMasterDisconnected(wxEvent& event);
};

} // namespace rxtools

#endif
